pub fn remove_session_transcript(
transcript_path: &Path,
) -> Result<SessionArtifactCleanupReport, SessionError>Expand description
Removes only the transcript, the final discoverability commit point.
pub fn remove_session_transcript(
transcript_path: &Path,
) -> Result<SessionArtifactCleanupReport, SessionError>Removes only the transcript, the final discoverability commit point.