pub struct SessionBranch {
pub root_id: String,
pub entries: Vec<SessionEntry>,
}Expand description
A linear branch within a session.
A branch is a sequence of entries sharing a common root. Branches are created
via Session::fork and are identified by a unique branch ID.
Fields
root_id: StringID of the root entry this branch originates from.
entries: Vec<SessionEntry>Ordered entries in this branch.