pub struct SessionMetadata {
pub turn_id: Option<String>,
pub provider: Option<String>,
pub model: Option<String>,
pub token_count: Option<u32>,
pub working_directory: Option<String>,
pub reasoning: Option<AssistantReasoning>,
pub raw_content: Option<String>,
}Expand description
Metadata associated with a session entry.
Captures optional context about the model, token usage, and working directory at the time the entry was created.
Fields
turn_id: Option<String>Durable runtime turn that committed this entry, when applicable.
provider: Option<String>model: Option<String>token_count: Option<u32>working_directory: Option<String>reasoning: Option<AssistantReasoning>raw_content: Option<String>Trait Implementations
Sourceimpl Clone for SessionMetadata
impl Clone for SessionMetadata
Sourcefn clone(&self) -> SessionMetadata
fn clone(&self) -> SessionMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionMetadata
impl Debug for SessionMetadata
Sourceimpl Default for SessionMetadata
impl Default for SessionMetadata
Sourcefn default() -> SessionMetadata
fn default() -> SessionMetadata
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SessionMetadata
impl<'de> Deserialize<'de> for SessionMetadata
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more