pub enum TodoError {
Database(String),
Json(String),
NotFound(Uuid),
DependencyCycle {
parent_id: Uuid,
child_id: Uuid,
},
SelfDependency(Uuid),
}Expand description
Errors that can occur while reading or writing session todos.
Variants
Database(String)
A database operation failed.
Json(String)
JSON metadata could not be serialized or parsed.
NotFound(Uuid)
A todo id did not exist in the target session.
DependencyCycle
A dependency would create a cycle.
Fields
SelfDependency(Uuid)
A todo cannot depend on itself.