TodoUpdateTool

Struct TodoUpdateTool 

pub struct TodoUpdateTool { /* private fields */ }
Agent tool that updates mutable fields on a session todo item.

Implementations

Source

impl TodoUpdateTool

pub fn new(db_path: PathBuf, session_id: Uuid) -> Self

Create a todo update tool bound to one session’s SQLite database path.

pub fn from_sessions_dir(sessions_dir: &Path, session_id: Uuid) -> Self

Create a todo update tool bound to one session, using the standard database path under a sessions directory.